@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -419,7 +419,7 @@ class PartnersClient(AbstractClient):
 
 
     def DescribeClientBalance(self, request):
-        """为合作伙伴提供查询客户余额能力。调用者必须是合作伙伴，只能查询自己名下客户余额
+        """【该接口将逐步下线，请切换使用升级版本DescribeClientBalanceNew】为合作伙伴提供查询客户余额能力。调用者必须是合作伙伴，只能查询自己名下客户余额.
 
         :param request: Request instance for DescribeClientBalance.
         :type request: :class:`tencentcloud.partners.v20180321.models.DescribeClientBalanceRequest`
@@ -446,22 +446,20 @@ class PartnersClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DescribeClientBaseInfo(self, request):
-        """该接口即将下线，请切换调用DescribeClientBasicInfo。
+    def DescribeClientBalanceNew(self, request):
+        """为合作伙伴提供查询客户余额能力。调用者必须是合作伙伴，只能查询自己名下客户余额
 
-        国际站根据UIN查询代客基础信息【本接口仅限主账号访问】
-
-        :param request: Request instance for DescribeClientBaseInfo.
-        :type request: :class:`tencentcloud.partners.v20180321.models.DescribeClientBaseInfoRequest`
-        :rtype: :class:`tencentcloud.partners.v20180321.models.DescribeClientBaseInfoResponse`
+        :param request: Request instance for DescribeClientBalanceNew.
+        :type request: :class:`tencentcloud.partners.v20180321.models.DescribeClientBalanceNewRequest`
+        :rtype: :class:`tencentcloud.partners.v20180321.models.DescribeClientBalanceNewResponse`
 
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeClientBaseInfo", params)
+            body = self.call("DescribeClientBalanceNew", params)
             response = json.loads(body)
             if "Error" not in response["Response"]:
-                model = models.DescribeClientBaseInfoResponse()
+                model = models.DescribeClientBalanceNewResponse()
                 model._deserialize(response["Response"])
                 return model
             else:
